@@ -18,7 +18,7 @@ from ACE_utils     import apply_blacklist
 from ACE_settings  import ACESettings
 from ACE_encoding  import ACEEncodingDecodeException
 
-version = '0.0.10'
+version = '0.0.11'
 
 langLookup = {
     3: QString.fromUtf8('English (United Kingdom)'),
@@ -42,7 +42,7 @@ langLookup = {
 }
 
 delModes = QStringList(('Normal', 'Confirm', 'OnClick', 'Blacklist'))
-encodings = QStringList(('Default', 'CP1252', 'ISO8859-1', 'ISO8859-2', 'ISO8859-3', 'ISO8859-4', 'ISO8859-5', 'ISO8859-6', 'ISO8859-7', 'ISO8859-8', 'ISO8859-9', 'ISO8859-10', 'ISO8859-11', 'ISO8859-13', 'ISO8859-14', 'ISO8859-15', 'ISO8859-16', 'UTF-8'))
+encodings = QStringList(('Default', 'CP1251', 'CP1252', 'CP1253', 'CP1254', 'CP1255', 'CP1256', 'CP1257', 'CP1258', 'CP874', 'ISO8859-1', 'ISO8859-2', 'ISO8859-3', 'ISO8859-4', 'ISO8859-5', 'ISO8859-6', 'ISO8859-7', 'ISO8859-8', 'ISO8859-9', 'ISO8859-10', 'ISO8859-11', 'ISO8859-13', 'ISO8859-14', 'ISO8859-15', 'ISO8859-16', 'UTF-8'))
 
 class ACEAboutWindow(QDialog): #{{{1
     def __init__(self, parent): #{{{2
